[tor-commits] [tor/master] Add doc/WritingTests.txt to distribution

2015-09-03 Thread nickm
commit 1d514b8a91c7cea03b636156977d40b34802f8d6
Author: Nick Mathewson 
Date:   Thu Sep 3 10:30:54 2015 -0400

Add doc/WritingTests.txt to distribution
---
 doc/include.am |4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/doc/include.am b/doc/include.am
index ff2de84..41d3d2a 100644
--- a/doc/include.am
+++ b/doc/include.am
@@ -37,7 +37,9 @@ endif
 EXTRA_DIST+= doc/HACKING doc/asciidoc-helper.sh\
  $(html_in) $(man_in) $(txt_in)\
  doc/state-contents.txt\
- doc/torrc_format.txt doc/TUNING
+ doc/torrc_format.txt  \
+doc/TUNING \
+doc/WritingTests.txt
 
 docdir = @docdir@
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Only return 0..255 from main().

2015-09-03 Thread nickm
commit e73206f68184a0d571a875044cf0a2cb6090f454
Author: Nick Mathewson 
Date:   Thu Sep 3 11:38:00 2015 -0400

Only return 0..255 from main().

I think this may fix some bugs with windows exit codes being screwy.
---
 changes/normalize_exit |3 +++
 src/or/tor_main.c  |6 +-
 2 files changed, 8 insertions(+), 1 deletion(-)

diff --git a/changes/normalize_exit b/changes/normalize_exit
new file mode 100644
index 000..636d45a
--- /dev/null
+++ b/changes/normalize_exit
@@ -0,0 +1,3 @@
+  o Minor features:
+- Try harder to normalize the exit status of the Tor process to the
+  standard-provided range.
diff --git a/src/or/tor_main.c b/src/or/tor_main.c
index af03b8c..65bb020 100644
--- a/src/or/tor_main.c
+++ b/src/or/tor_main.c
@@ -27,6 +27,10 @@ int tor_main(int argc, char *argv[]);
 int
 main(int argc, char *argv[])
 {
-  return tor_main(argc, argv);
+  int r = tor_main(argc, argv);
+  if (r < 0 || r > 255)
+return 1;
+  else
+return r;
 }
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Add a little more output to test_keygen.sh: try to debug windows

2015-09-03 Thread nickm
commit 91ca434451064ef00532c4f8e4b098f2b1c516d1
Author: Nick Mathewson 
Date:   Thu Sep 3 10:53:04 2015 -0400

Add a little more output to test_keygen.sh: try to debug windows
---
 src/test/test_keygen.sh |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/test_keygen.sh b/src/test/test_keygen.sh
index e8e3c3d..d6066ac 100755
--- a/src/test/test_keygen.sh
+++ b/src/test/test_keygen.sh
@@ -109,7 +109,7 @@ check_file "${DATA_DIR}/encrypted/keys/ed25519_signing_cert"
 check_file "${DATA_DIR}/encrypted/keys/ed25519_signing_secret_key"
 
 
-echo "=== Starting tests."
+echo "=== Starting keygen tests."
 
 #
 # The "case X" numbers below come from s7r's email on
@@ -124,7 +124,7 @@ ME="${DATA_DIR}/case2a"
 SRC="${DATA_DIR}/orig"
 mkdir -p "${ME}/keys"
 cp "${SRC}/keys/ed25519_master_id_public_key" "${ME}/keys/"
-${TOR} --DataDirectory "${ME}" --list-fingerprint > "${ME}/stdout" && die 
"Somehow succeeded when missing secret key, certs" || true
+${TOR} --DataDirectory "${ME}" --list-fingerprint > "${ME}/stdout" && die 
"Somehow succeeded when missing secret key, certs: `cat ${ME}/stdout`" || true
 check_files_eq "${SRC}/keys/ed25519_master_id_public_key" 
"${ME}/keys/ed25519_master_id_public_key"
 
 grep "We needed to load a secret key.*but couldn't find it" "${ME}/stdout" 
>/dev/null || die "Tor didn't declare that it was missing a secret key"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Use absolute path for datadir in test_keygen.sh

2015-09-03 Thread nickm
commit 604a18e680ef139513ba630391f655fb6394eae1
Author: Nick Mathewson 
Date:   Thu Sep 3 14:53:50 2015 -0400

Use absolute path for datadir in test_keygen.sh
---
 src/test/test_keygen.sh |3 +++
 1 file changed, 3 insertions(+)

diff --git a/src/test/test_keygen.sh b/src/test/test_keygen.sh
index 6e852a9..917a804 100755
--- a/src/test/test_keygen.sh
+++ b/src/test/test_keygen.sh
@@ -65,6 +65,9 @@ if [ ! -d "$DATA_DIR" ]; then
 fi
 trap "rm -rf '$DATA_DIR'" 0
 
+# Use an absolute path for this or Tor will complain
+DATA_DIR=`cd "${DATA_DIR}" && pwd`
+
 touch "${DATA_DIR}/empty_torrc"
 
 QUIETLY="--hush"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Now normalize_exit has a bug number.

2015-09-03 Thread nickm
commit aa430c72254c56bad00900d4ad676d6c4529bff0
Author: Nick Mathewson 
Date:   Thu Sep 3 15:10:57 2015 -0400

Now normalize_exit has a bug number.
---
 changes/normalize_exit |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/changes/normalize_exit b/changes/normalize_exit
index 636d45a..300aace 100644
--- a/changes/normalize_exit
+++ b/changes/normalize_exit
@@ -1,3 +1,4 @@
   o Minor features:
 - Try harder to normalize the exit status of the Tor process to the
-  standard-provided range.
+  standard-provided range. Fixes bug 16975; bugfix on every version
+  of Tor ever.

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Try to fix #16974; bug not in any released version

2015-09-03 Thread nickm
commit b63034ce3e5ffd46ad37294dabe742d6b23366ba
Author: Nick Mathewson 
Date:   Thu Sep 3 14:42:50 2015 -0400

Try to fix #16974; bug not in any released version
---
 configure.ac |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/configure.ac b/configure.ac
index 984a708..eacb60e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -639,7 +639,7 @@ AC_TRY_COMPILE([
 #error "too old"
 #endif
], [],
-   [ ],
+   [ /bin/true ],
[ AC_ERROR([OpenSSL is too old. We require 1.0.0 or later. You can specify 
a path to a newer one with --with-openssl-dir.]) ])
 
 AC_CHECK_MEMBERS([struct ssl_method_st.get_cipher_by_char], , ,

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Fix windows test_keygen.sh. This time I think I have it!

2015-09-03 Thread nickm
commit 81e58cd00a918c8590f564fda3aa950156a70337
Author: Nick Mathewson 
Date:   Thu Sep 3 15:23:10 2015 -0400

Fix windows test_keygen.sh. This time I think I have it!
---
 src/test/test_keygen.sh |   17 +
 1 file changed, 9 insertions(+), 8 deletions(-)

diff --git a/press/en/press.wml b/press/en/press.wml
index 600866d..b2e4272 100644
--- a/press/en/press.wml
+++ b/press/en/press.wml
@@ -50,77 +50,77 @@ some of the significant Tor-related stories that have 
popped up.
 
 
 
-August 31, 2015
+2015 Aug 31
 Statesman
 http://www.statesman.com/news/technology/tor-is-software-for-keeping-things-online-anonymou/nnR7z/;>‘Tor’
 is software for keeping things online anonymous
 
 
-August 29,2015
+2015 Aug 29
 Saturday Paper
 https://www.thesaturdaypaper.com.au/2015/08/29/tor-and-the-deep-web-going-mainstream/14407704002293;>Tor
 and the Deep Web Going Mainstream
 
 
-August 28, 2015
+2015 Aug 28
 SC MAGAZINE
 http://www.scmagazine.com/dark-website-agora-closes-over-tor-vulnerability-suspicions/article/435278/;>Dark
 website Agora closes over Tor vulnerability suspicions
 
 
-July 31, 2015
+2015 Jul 31
 SC Magazine
 http://www.scmagazine.com/tor-project-library-freedom-project-to-establish-tor-exit-nodes-in-libraries/article/429867/;>Tor
 Project, Library Freedom Project to establish Tor exit nodes in 
libraries
 
 
-July 24, 2015
+2015 Jul 24
 WHYY Radio
 https://technical.ly/philly/2015/07/24/kate-krauss-radio-times/;>Security 
and Privacy on the Internet, with Julia Angwen and Tor Project’s Kate Krauss 
(starts at 13:30)
 
 
-July 16, 2015
+2015 Jul 16
 Technically Philly
 https://technical.ly/philly/2015/07/16/kate-krauss-tor/;>How this 
West Philly activist became Tor’s first director of communications
 
 
-July 8, 2015
+2015 Jul 8
 Technically Philly
 https://technical.ly/philly/2015/07/08/philadelphia-internet-privacy-tor/;>Inside
 Philly’s Growing Internet Privacy Community
 
 
-June 13, 2015
+2015 Jun 13
 CNN
 http://money.cnn.com/2014/06/13/technology/security/dont-get-hacked/index.html;>Simple
 tips to avoid getting hacked
 
 
-June 30, 2015
+2015 Jun 30
 Ars Technica
 http://arstechnica.com/tech-policy/2015/07/crypto-activists-announce-vision-for-tor-exit-relay-in-every-library/;>Crypto
 activists announce vision for Tor exit relay in every library "Librarians see 
the value as soon as you say ‘privacy protecting technology.'" 
 
 
-June 18, 2015
+2015 Jun 18
 WIRED
 http://www.wired.com/2015/06/dark-web-know-myth/;>The Dark Web as 
You Know It Is a Myth
 
 
-June 18, 2015
+2015 Jun 18
 Liberation
 http://www.liberation.fr/economie/2015/06/18/tor-mails-toi-de-tes-oignons_1332660;>Tor:
 "The emancipatory use of technology"
 
 
-2015 April 9
+2015 Apr 9
 Silicon Republic
 http://www.siliconrepublic.com/enterprise/item/41531-the-interview-runa-sandvik;>Interview
 with Runa Sandvik
 
 
-2015 April 4
+2015 Apr 4
 El Pais
 http://tecnologia.elpais.com/tecnologia/2015/04/04/actualidad/1428169979_196077.html;>Hay
 que lograr que Internet deje de ser un medio de vigilancia masiva 
 
 
-2015 April 2
+2015 Apr 2
 Motherboard 
 http://motherboard.vice.com/read/tor-wants-to-know-how-to-make-the-darknet-mainstream;>Tor
 wants to know how to make the darknet mainstream
 
 
-2015 March 26
+2015 Mar 26
 Daily Dot
 http://www.dailydot.com/politics/tor-media-public-relations-perception/;>Tor's
 great rebranding
 
@@ -172,7 +172,7 @@ 
href="http://insidebitcoins.com/news/developers-say-privacy-network-tor-was-not-
 Say Privacy Network Tor Was Not Compromised During Silk Road Takedown
 
 
-January 29, 2015
+2015 Jan 29
 The Inquirer
 http://www.theinquirer.net/inquirer/news/2392703/mozilla-treats-tor-network-to-a-hardware-helping-hand;>Mozilla
 treats Tor Network to a hardware helping hand

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor/master] Make test_keygen.sh dump what the problem is on cmp failure

2015-09-03 Thread nickm
commit ffb56863aa82ca55c8a98853a9258a04e6f927e0
Author: Nick Mathewson 
Date:   Thu Sep 3 12:51:58 2015 -0400

Make test_keygen.sh dump what the problem is on cmp failure
---
 src/test/test_keygen.sh |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/src/test/test_keygen.sh b/src/test/test_keygen.sh
index d6066ac..6e852a9 100755
--- a/src/test/test_keygen.sh
+++ b/src/test/test_keygen.sh
@@ -46,11 +46,12 @@ fi
   fi
 
 
+dump() { xxd -p "$1" | tr -d '\n '; }
 die() { echo "$1" >&2 ; exit 5; }
 check_dir() { [ -d "$1" ] || die "$1 did not exist"; }
 check_file() { [ -e "$1" ] || die "$1 did not exist"; }
 check_no_file() { [ -e "$1" ] && die "$1 was not supposed to exist" || true; }
-check_files_eq() { cmp "$1" "$2" || die "$1 and $2 did not match"; }
+check_files_eq() { cmp "$1" "$2" || die "$1 and $2 did not match: `dump $1` vs 
`dump $2`"; }
 check_keys_eq() { check_files_eq "${SRC}/keys/${1}" "${ME}/keys/${1}"; }
 
 DATA_DIR=`mktemp -d -t tor_keygen_tests.XX`

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-launcher-network-settings_completed] Update translations for tor-launcher-network-settings_completed

2015-09-03 Thread translation
commit f7ca73186799c036404bb91f4f8a732d023751fa
Author: Translation commit bot 
Date:   Thu Sep 3 17:45:39 2015 +

Update translations for tor-launcher-network-settings_completed
---
 fr/network-settings.dtd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/fr/network-settings.dtd b/fr/network-settings.dtd
index 6533fd2..566dfe1 100644
--- a/fr/network-settings.dtd
+++ b/fr/network-settings.dtd
@@ -15,7 +15,7 @@
 
 
 
-
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-launcher-network-settings] Update translations for tor-launcher-network-settings

2015-09-03 Thread translation
commit d7e8cdc61365cd1767a8aea977ab0f09d25ff894
Author: Translation commit bot 
Date:   Thu Sep 3 17:45:36 2015 +

Update translations for tor-launcher-network-settings
---
 fr/network-settings.dtd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/fr/network-settings.dtd b/fr/network-settings.dtd
index 6533fd2..566dfe1 100644
--- a/fr/network-settings.dtd
+++ b/fr/network-settings.dtd
@@ -15,7 +15,7 @@
 
 
 
-
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [onionoo/master] Add OnionView to the list of known clients.

2015-09-03 Thread karsten
commit b253764c74624433ec24219f7da0b6ccd9280075
Author: Karsten Loesing 
Date:   Thu Sep 3 08:16:44 2015 +0200

Add OnionView to the list of known clients.
---
 web/index.html |3 +++
 1 file changed, 3 insertions(+)

diff --git a/web/index.html b/web/index.html
index c159fc4..124c7b2 100644
--- a/web/index.html
+++ b/web/index.html
@@ -61,6 +61,9 @@ a simple Java command line interface for querying Onionoo 
data.
 The https://duckduckgo.com/;>DuckDuckGo search engine
 displays Tor node details when being asked for "tor node" followed by a
 search term.
+https://onionview.com/;>OnionView is a simple web service
+which uses Tor relay data to plot the location of active Tor nodes onto an
+interactive map of the world.
 
 
 The following library facilitates development of Onionoo clients:

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/master] Update Tor Browser key

2015-09-03 Thread gk
commit b5533d49b8dbc8b24ffddae56623bb38e380875f
Author: Georg Koppen 
Date:   Thu Sep 3 07:12:38 2015 +

Update Tor Browser key
---
 gitian/gpg/torbrowser.gpg |  Bin 6015 -> 18844 bytes
 1 file changed, 0 insertions(+), 0 deletions(-)

diff --git a/gitian/gpg/torbrowser.gpg b/gitian/gpg/torbrowser.gpg
index 7267d4d..dc44e33 100644
Binary files a/gitian/gpg/torbrowser.gpg and b/gitian/gpg/torbrowser.gpg differ

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/maint-5.0] Update Tor Browser key

2015-09-03 Thread gk
commit ce86c32d1160983b08775cd154f22dbb3d303947
Author: Georg Koppen 
Date:   Thu Sep 3 07:28:33 2015 +

Update Tor Browser key
---
 gitian/gpg/torbrowser.gpg |  Bin 6015 -> 18844 bytes
 1 file changed, 0 insertions(+), 0 deletions(-)

diff --git a/gitian/gpg/torbrowser.gpg b/gitian/gpg/torbrowser.gpg
index 7267d4d..dc44e33 100644
Binary files a/gitian/gpg/torbrowser.gpg and b/gitian/gpg/torbrowser.gpg differ



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/maint-5.0] Bug 16948: Download PyCrypto from pypi.python.org

2015-09-03 Thread gk
commit 8610ac13cda8ba91d2baba93c28c7fd726ca3c7c
Author: Georg Koppen 
Date:   Wed Sep 2 08:46:07 2015 +

Bug 16948: Download PyCrypto from pypi.python.org
---
 gitian/versions |2 +-
 gitian/versions.alpha   |2 +-
 gitian/versions.beta|2 +-
 gitian/versions.nightly |2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/gitian/versions b/gitian/versions
index f5e4331..c0b86ea 100755
--- a/gitian/versions
+++ b/gitian/versions
@@ -111,7 +111,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.alpha b/gitian/versions.alpha
index 4692c16..a0d64c7 100755
--- a/gitian/versions.alpha
+++ b/gitian/versions.alpha
@@ -111,7 +111,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.beta b/gitian/versions.beta
index 0341c4e..d743c89 100755
--- a/gitian/versions.beta
+++ b/gitian/versions.beta
@@ -104,7 +104,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/storage/public-staging/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.nightly b/gitian/versions.nightly
index 1874859..0ca40a2 100755
--- a/gitian/versions.nightly
+++ b/gitian/versions.nightly
@@ -114,7 +114,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/master] Bug 16948: Download PyCrypto from pypi.python.org

2015-09-03 Thread gk
commit ca56d487d9d59d59e1d7e9b4af760379ac0f876b
Author: Georg Koppen 
Date:   Wed Sep 2 08:46:07 2015 +

Bug 16948: Download PyCrypto from pypi.python.org
---
 gitian/versions |2 +-
 gitian/versions.alpha   |2 +-
 gitian/versions.beta|2 +-
 gitian/versions.nightly |2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/gitian/versions b/gitian/versions
index 671b500..3df967e 100755
--- a/gitian/versions
+++ b/gitian/versions
@@ -115,7 +115,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.alpha b/gitian/versions.alpha
index e722408..5005445 100755
--- a/gitian/versions.alpha
+++ b/gitian/versions.alpha
@@ -115,7 +115,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.beta b/gitian/versions.beta
index 4436010..343d4b5 100755
--- a/gitian/versions.beta
+++ b/gitian/versions.beta
@@ -108,7 +108,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/storage/public-staging/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}
diff --git a/gitian/versions.nightly b/gitian/versions.nightly
index 1308302..afb82c5 100755
--- a/gitian/versions.nightly
+++ b/gitian/versions.nightly
@@ -118,7 +118,7 @@ 
GCC_URL=https://ftp.gnu.org/gnu/gcc/gcc-${GCC_VER}/${GCC_PACKAGE}
 
NOSCRIPT_URL=https://addons.cdn.mozilla.net/user-media/addons/722/${NOSCRIPT_PACKAGE}
 PYTHON_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_PACKAGE}
 
PYTHON_MSI_URL=https://www.python.org/ftp/python/${PYTHON_VER}/${PYTHON_MSI_PACKAGE}
-PYCRYPTO_URL=https://ftp.dlitz.net/pub/dlitz/crypto/pycrypto/${PYCRYPTO_PACKAGE}
+PYCRYPTO_URL=https://pypi.python.org/packages/source/p/pycrypto/${PYCRYPTO_PACKAGE}
 ARGPARSE_URL=https://argparse.googlecode.com/files/${ARGPARSE_PACKAGE}
 PYYAML_URL=https://pypi.python.org/packages/source/P/PyYAML/${PYYAML_PACKAGE}
 
ZOPEINTERFACE_URL=https://pypi.python.org/packages/source/z/zope.interface/${ZOPEINTERFACE_PACKAGE}

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-messenger-ircproperties] Update translations for tor-messenger-ircproperties

2015-09-03 Thread translation
commit d86d1388c52e564f01d37b4eb31f2ae4e0cb741e
Author: Translation commit bot 
Date:   Thu Sep 3 09:46:38 2015 +

Update translations for tor-messenger-ircproperties
---
 hr_HR/irc.properties |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/hr_HR/irc.properties b/hr_HR/irc.properties
index 1523ea6..5aaa70b 100644
--- a/hr_HR/irc.properties
+++ b/hr_HR/irc.properties
@@ -103,9 +103,9 @@ message.nick.you=You are now known as %S.
 #Could not change the nickname. %S is the user's nick.
 message.nick.fail=Nije moguće koristiti željeni nadimak. Vaš nadimak ostaje 
%S.
 #The parameter is the message.parted.reason, if a part message is given.
-message.parted.you=You have left the room (Part%1$S).
+message.parted.you=Napustili ste sobu (Part%1$S).
 #%1$S is the user's nick, %2$S is message.parted.reason, if a part message 
is given.
-message.parted=%1$S has left the room (Part%2$S).
+message.parted=%1$S je napustio sobu (Part%2$S).
 #%S is the part message supplied by the user.
 message.parted.reason=: %S
 #%1$S is the user's nick, %2$S is message.quit2 if a quit message is given.

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-messenger-otrproperties] Update translations for tor-messenger-otrproperties

2015-09-03 Thread translation
commit 53cbc68fdba87fba6350e20865c01a0cb02eebfa
Author: Translation commit bot 
Date:   Thu Sep 3 10:16:27 2015 +

Update translations for tor-messenger-otrproperties
---
 hr_HR/otr.properties |   50 +-
 1 file changed, 25 insertions(+), 25 deletions(-)

diff --git a/hr_HR/otr.properties b/hr_HR/otr.properties
index 07a14ec..9190510 100644
--- a/hr_HR/otr.properties
+++ b/hr_HR/otr.properties
@@ -1,28 +1,28 @@
-msgevent.encryption_required_part1=You attempted to send an unencrypted 
message to %S. As a policy, unencrypted messages are not allowed.
-msgevent.encryption_required_part2=Attempting to start a private conversation. 
Your message will be retransmitted when the private conversation starts.
-msgevent.encryption_error=An error occurred when encrypting your message. The 
message was not sent.
-msgevent.connection_ended=%S has already closed their private connection to 
you. Your message was not sent. Either end your private conversation, or 
restart it.
-msgevent.setup_error=An error occured while setting up a private conversation 
with %S.
-msgevent.msg_reflected=You are receiving your own OTR messages. You are either 
trying to talk to yourself, or someone is reflecting your messages back at you.
-msgevent.msg_resent=The last message to %S was resent.
-msgevent.rcvdmsg_not_private=The encrypted message received from %S is 
unreadable, as you are not currently communicating privately.
-msgevent.rcvdmsg_unreadable=We received an unreadable encrypted message from 
%S.
-msgevent.rcvdmsg_malformed=We received a malformed data message from %S.
-msgevent.log_heartbeat_rcvd=Heartbeat received from %S.
-msgevent.log_heartbeat_sent=Heartbeat sent to %S.
-msgevent.rcvdmsg_general_err=An OTR error occured.
-msgevent.rcvdmsg_unecrypted=We received an unencrypted message from %S.
-msgevent.rcvdmsg_unrecognized=We received an unrecognized OTR message from %S.
-msgevent.rcvdmsg_for_other_instance=%S has sent a message intended for a 
different session. If you are logged in multiple times, another session may 
have received the message.
-context.gone_secure_private=Private conversation with %S started.
-context.gone_secure_unverified=Private conversation with %S started. However, 
their identity has not been verified.
-context.still_secure=Successfully refreshed the private conversation with %S.
-error.enc=Error occurred encrypting message.
-error.not_priv=You sent encrypted data to %S, who wasn't expecting it.
-error.unreadable=You transmitted an unreadable encrypted message.
-error.malformed=You transmitted a malformed data message.
-resent=[resent]
-tlv.disconnected=%S has ended their private conversation with you; you should 
do the same.
+msgevent.encryption_required_part1=Pokušali ste poslati neenkriptiranu poruku 
%S. Neenkriptirane poruke nisu dozvoljene.
+msgevent.encryption_required_part2=Pokušavam započeti privatni razgovor. 
Vaša poruka će biti ponovno poslana kad privatni razgovor započne.
+msgevent.encryption_error=Došlo je do pogreške prilikom enkripcije Vaše 
poruke. Poruka nije poslana.
+msgevent.connection_ended=%S je već zatvorio svoju privatnu vezu prema Vama. 
Vaša poruka nije poslana. Ili završite svoj privatni razgovor ili ga ponovno 
pokrenite.
+msgevent.setup_error=Došlo je do pogreške prilikom uspostave privatnog 
razgovora s %S.
+msgevent.msg_reflected=Primate vlastite OTR poruke. Ili želite pričati sami 
sa sobom, ili netko reflektira Vaše poruke natrag Vama.
+msgevent.msg_resent=Posljednja poruka za %S je poslana ponovno.
+msgevent.rcvdmsg_not_private=Enkriptirana poruka primljena od %S je 
nečitljiva, jer trenutno ne komunicirate privatno.
+msgevent.rcvdmsg_unreadable=Primili smo nečitljivu enkriptiranu poruku od %S.
+msgevent.rcvdmsg_malformed=Primili smo poruku o malformiranim podatcima od %S.
+msgevent.log_heartbeat_rcvd=Otkucaj srca primljen od %S.
+msgevent.log_heartbeat_sent=Otkucaj srca poslan prema %S.
+msgevent.rcvdmsg_general_err=Došlo je do OTR pogreške.
+msgevent.rcvdmsg_unecrypted=Primili smo neenkriptiranu poruku od %S.
+msgevent.rcvdmsg_unrecognized=Primili smo neprepoznatu OTR poruku od %S.
+msgevent.rcvdmsg_for_other_instance=%S je poslao poruku namjenjenu za 
različitu sesiju. Ako ste prijavljeni više puta, možda je neka druga sesija 
primila tu poruku.
+context.gone_secure_private=Privatni razgovor s %S pokrenut.
+context.gone_secure_unverified=Privatni razgovor s %S pokrenut. Kako bilo, 
identitet kontakta nije verificiran.
+context.still_secure=Uspješno osvježen privatni razgovor s %S.
+error.enc=Došlo je do pogreške prilikom enkripcije poruke.
+error.not_priv=Poslali ste enkriptirane podatke prema %S, koji to nije 
očekivao.
+error.unreadable=Poslali ste nečitljivu enkriptiranu poruku.
+error.malformed=Poslali ste poruku malformiranih podataka.
+resent=[ponovno poslano]
+tlv.disconnected=%S je završio privatni razgovor s Vama; i Vi bi trebali 

[tor-commits] [translation/tor-messenger-authproperties] Update translations for tor-messenger-authproperties

2015-09-03 Thread translation
commit 1ad069bbf813cea6f61db609acef8e0fce457d81
Author: Translation commit bot 
Date:   Thu Sep 3 09:46:19 2015 +

Update translations for tor-messenger-authproperties
---
 hr_HR/auth.properties |   14 +++---
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/hr_HR/auth.properties b/hr_HR/auth.properties
index c3b4403..3c57b7c 100644
--- a/hr_HR/auth.properties
+++ b/hr_HR/auth.properties
@@ -1,12 +1,12 @@
 auth.title=Verificiraj identitet %S.
 auth.yourFingerprint=Otisak prsta za Vas, %S:\n%S
 auth.theirFingerprint=Navodni otisak prsta za %S:\n%S
-auth.help=Verifying a contact's identity helps ensure that the person you are 
talking to is who they claim to be.
-auth.helpTitle=Verification help
-auth.question=This is the question asked by your contact:\n\n%S\n\nEnter 
secret answer here (case sensitive):
+auth.help=Verificiranje identiteta kontakta osigurava da je osoba s kojom 
razgovarate uistinu onaj za kog se predstavlja.
+auth.helpTitle=Pomoć pri verifikaciji
+auth.question=Ovo je pitanje koje pita Vaš kontakt:\n\n%S\n\nUnesite tajni 
odgovor ovdje (osjetljivo na velika i mala slova):
 auth.secret=Unesite tajnu ovdje:
-auth.error=An error occurred while verifying your contact's identity.
-auth.success=Verifying your contact's identity completed successfully.
-auth.successThem=Your contact has successfully verified your identity. You may 
want to verify their identity as well by asking your own question.
-auth.fail=Failed to verify your contact's identity.
+auth.error=Došlo je do pogreške prilikom verificiranja identiteta Vašeg 
kontakta.
+auth.success=Verificiranje identiteta Vašeg kontakta uspješno dovršeno.
+auth.successThem=Vaš kontakt je uspješno verificirao Vaš identitet. Možda 
bi htjeli verificirati njihov identitet postavljanjem svog pitanja.
+auth.fail=Nije uspjelo verificiranje identiteta Vašeg kontakta.
 auth.done=Gotovo

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tor-messenger-authproperties_completed] Update translations for tor-messenger-authproperties_completed

2015-09-03 Thread translation
commit 502d5dc86392703867bac6105e51b474b2f63460
Author: Translation commit bot 
Date:   Thu Sep 3 09:46:23 2015 +

Update translations for tor-messenger-authproperties_completed
---
 hr_HR/auth.properties |   12 
 1 file changed, 12 insertions(+)

diff --git a/hr_HR/auth.properties b/hr_HR/auth.properties
new file mode 100644
index 000..3c57b7c
--- /dev/null
+++ b/hr_HR/auth.properties
@@ -0,0 +1,12 @@
+auth.title=Verificiraj identitet %S.
+auth.yourFingerprint=Otisak prsta za Vas, %S:\n%S
+auth.theirFingerprint=Navodni otisak prsta za %S:\n%S
+auth.help=Verificiranje identiteta kontakta osigurava da je osoba s kojom 
razgovarate uistinu onaj za kog se predstavlja.
+auth.helpTitle=Pomoć pri verifikaciji
+auth.question=Ovo je pitanje koje pita Vaš kontakt:\n\n%S\n\nUnesite tajni 
odgovor ovdje (osjetljivo na velika i mala slova):
+auth.secret=Unesite tajnu ovdje:
+auth.error=Došlo je do pogreške prilikom verificiranja identiteta Vašeg 
kontakta.
+auth.success=Verificiranje identiteta Vašeg kontakta uspješno dovršeno.
+auth.successThem=Vaš kontakt je uspješno verificirao Vaš identitet. Možda 
bi htjeli verificirati njihov identitet postavljanjem svog pitanja.
+auth.fail=Nije uspjelo verificiranje identiteta Vašeg kontakta.
+auth.done=Gotovo

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator] Update translations for liveusb-creator

2015-09-03 Thread translation
commit 20ab22a629dd6b35007d3f5f9b0e31e16fe42b1a
Author: Translation commit bot 
Date:   Thu Sep 3 09:45:24 2015 +

Update translations for liveusb-creator
---
 hr_HR/hr_HR.po |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/hr_HR/hr_HR.po b/hr_HR/hr_HR.po
index 5b0a4e1..6a61503 100644
--- a/hr_HR/hr_HR.po
+++ b/hr_HR/hr_HR.po
@@ -13,7 +13,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2015-08-10 16:01+0200\n"
-"PO-Revision-Date: 2015-08-12 08:46+\n"
+"PO-Revision-Date: 2015-09-03 09:37+\n"
 "Last-Translator: skiddiep \n"
 "Language-Team: Croatian (Croatia) 
(http://www.transifex.com/otf/torproject/language/hr_HR/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/https_everywhere] Update translations for https_everywhere

2015-09-03 Thread translation
commit 54719e165c37d4a2372e177d8b32164a8a95b788
Author: Translation commit bot 
Date:   Thu Sep 3 09:45:15 2015 +

Update translations for https_everywhere
---
 hr_HR/https-everywhere.dtd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/hr_HR/https-everywhere.dtd b/hr_HR/https-everywhere.dtd
index b42ef3e..11a4e07 100644
--- a/hr_HR/https-everywhere.dtd
+++ b/hr_HR/https-everywhere.dtd
@@ -17,7 +17,7 @@
 
 
 
-
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/https_everywhere_completed] Update translations for https_everywhere_completed

2015-09-03 Thread translation
commit 3f71d784b167e53195103c287d36682a7ef7
Author: Translation commit bot 
Date:   Thu Sep 3 09:45:19 2015 +

Update translations for https_everywhere_completed
---
 hr_HR/https-everywhere.dtd |1 +
 1 file changed, 1 insertion(+)

diff --git a/hr_HR/https-everywhere.dtd b/hr_HR/https-everywhere.dtd
index 96903e6..11a4e07 100644
--- a/hr_HR/https-everywhere.dtd
+++ b/hr_HR/https-everywhere.dtd
@@ -17,6 +17,7 @@
 
 
 
+
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator_completed] Update translations for liveusb-creator_completed

2015-09-03 Thread translation
commit a827f3d27c6ae4298f6c9e278fad5b9566c3fa49
Author: Translation commit bot 
Date:   Thu Sep 3 09:45:27 2015 +

Update translations for liveusb-creator_completed
---
 hr_HR/hr_HR.po |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/hr_HR/hr_HR.po b/hr_HR/hr_HR.po
index 5b0a4e1..6a61503 100644
--- a/hr_HR/hr_HR.po
+++ b/hr_HR/hr_HR.po
@@ -13,7 +13,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2015-08-10 16:01+0200\n"
-"PO-Revision-Date: 2015-08-12 08:46+\n"
+"PO-Revision-Date: 2015-09-03 09:37+\n"
 "Last-Translator: skiddiep \n"
 "Language-Team: Croatian (Croatia) 
(http://www.transifex.com/otf/torproject/language/hr_HR/)\n"
 "MIME-Version: 1.0\n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/master] Bug 16973: fix gpg keyring path

2015-09-03 Thread gk
commit 199808ddbe8e9f640bc8cef57e6f09f2f3070d95
Author: Nicolas Vigier 
Date:   Thu Sep 3 11:35:34 2015 +0200

Bug 16973: fix gpg keyring path

The path defined in config.yml is relative to the tools/update-responses
directory, but we usually run the script from the Makefile in the gitian
directory. This patch makes it work from anywhere.
---
 tools/update-responses/update_responses |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/tools/update-responses/update_responses 
b/tools/update-responses/update_responses
index 4f6286d..bb285fd 100755
--- a/tools/update-responses/update_responses
+++ b/tools/update-responses/update_responses
@@ -423,7 +423,7 @@ sub download_version {
 }
 }
 if (system('gpg', '--no-default-keyring', '--keyring',
-$config->{download}{gpg_keyring}, '--verify',
+"$FindBin::Bin/$config->{download}{gpg_keyring}", '--verify',
 "$tmpdir/sha256sums-unsigned-build.txt.asc",
 "$tmpdir/sha256sums-unsigned-build.txt")) {
 exit_error "Error checking gpg signature for version $version";



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/master] Bug 10140: Support platform specific langpacks

2015-09-03 Thread gk
commit 5b34c06405a5524a5bc2b8ba42fd0587086dd52c
Author: Yawning Angel 
Date:   Tue Sep 1 10:54:30 2015 +

Bug 10140: Support platform specific langpacks

This patch allows to fetch Linux/Windows/OSX-specific language packs.
Furthermore, it enables Japanese.
---
 gitian/descriptors/linux/gitian-bundle.yml   |3 ++-
 gitian/descriptors/mac/gitian-bundle.yml |3 ++-
 gitian/descriptors/windows/gitian-bundle.yml |3 ++-
 gitian/fetch-inputs.sh   |   20 
 gitian/versions  |4 
 gitian/versions.alpha|3 +++
 gitian/versions.beta |3 +++
 gitian/versions.nightly  |3 +++
 8 files changed, 39 insertions(+), 3 deletions(-)

diff --git a/gitian/descriptors/linux/gitian-bundle.yml 
b/gitian/descriptors/linux/gitian-bundle.yml
index f1d0554..afb632e 100644
--- a/gitian/descriptors/linux/gitian-bundle.yml
+++ b/gitian/descriptors/linux/gitian-bundle.yml
@@ -182,7 +182,8 @@ script: |
   #
   unzip linux-langpacks.zip
   cd linux-langpacks
-  for LANG in $BUNDLE_LOCALES
+  LINUX_LOCALES="$BUNDLE_LOCALES $BUNDLE_LOCALES_LINUX"
+  for LANG in $LINUX_LOCALES
   do
 xpi=$LANG.xpi
 cp -a ../tor-browser ../tor-browser_$LANG
diff --git a/gitian/descriptors/mac/gitian-bundle.yml 
b/gitian/descriptors/mac/gitian-bundle.yml
index a956fa7..dabe619 100644
--- a/gitian/descriptors/mac/gitian-bundle.yml
+++ b/gitian/descriptors/mac/gitian-bundle.yml
@@ -208,7 +208,8 @@ script: |
   #
   unzip mac-langpacks.zip
   cd mac-langpacks
-  for LANG in $BUNDLE_LOCALES
+  MAC_LOCALES="$BUNDLE_LOCALES $BUNDLE_LOCALES_MAC"
+  for LANG in $MAC_LOCALES
   do
 xpi=$LANG.xpi
 DEST=$TORBROWSER_APP
diff --git a/gitian/descriptors/windows/gitian-bundle.yml 
b/gitian/descriptors/windows/gitian-bundle.yml
index c674e1b..649ff53 100644
--- a/gitian/descriptors/windows/gitian-bundle.yml
+++ b/gitian/descriptors/windows/gitian-bundle.yml
@@ -173,7 +173,8 @@ script: |
   #
   unzip ../win32-langpacks.zip
   cd win32-langpacks
-  for LANG in $BUNDLE_LOCALES
+  WIN32_LOCALES="$BUNDLE_LOCALES $BUNDLE_LOCALES_WIN32"
+  for LANG in $WIN32_LOCALES
   do
 xpi=$LANG.xpi
 cp $xpi ../"Tor 
Browser"/Browser/TorBrowser/Data/Browser/profile.default/extensions/langpack-$l...@firefox.mozilla.org.xpi
diff --git a/gitian/fetch-inputs.sh b/gitian/fetch-inputs.sh
index a97ff62..42efa33 100755
--- a/gitian/fetch-inputs.sh
+++ b/gitian/fetch-inputs.sh
@@ -177,6 +177,7 @@ do
fi
 done
 
+# Fetch the common langpacks first, then the platform specific ones if any.
 mkdir -p langpacks-$FIREFOX_LANG_VER/linux-langpacks
 mkdir -p langpacks-$FIREFOX_LANG_VER/win32-langpacks
 mkdir -p langpacks-$FIREFOX_LANG_VER/mac-langpacks
@@ -196,6 +197,25 @@ do
   cd ..
 done
 
+for i in $BUNDLE_LOCALES_LINUX
+do
+  cd linux-langpacks
+  wget -U "" -N 
"https://ftp.mozilla.org/pub/mozilla.org/firefox/candidates/${FIREFOX_LANG_VER}-candidates/${FIREFOX_LANG_BUILD}/linux-i686/xpi/$i.xpi;
+  cd ..
+done
+for i in $BUNDLE_LOCALES_WIN32
+do
+  cd win32-langpacks
+  wget -U "" -N 
"https://ftp.mozilla.org/pub/mozilla.org/firefox/candidates/${FIREFOX_LANG_VER}-candidates/${FIREFOX_LANG_BUILD}/win32/xpi/$i.xpi;
+  cd ..
+done
+for i in $BUNDLE_LOCALES_MAC
+do
+  cd mac-langpacks
+  wget -U "" -N 
"https://ftp.mozilla.org/pub/mozilla.org/firefox/candidates/${FIREFOX_LANG_VER}-candidates/${FIREFOX_LANG_BUILD}/mac/xpi/$i.xpi;
+  cd ..
+done
+
 "$WRAPPER_DIR/build-helpers/dzip.sh" ../win32-langpacks.zip win32-langpacks
 "$WRAPPER_DIR/build-helpers/dzip.sh" ../linux-langpacks.zip linux-langpacks
 "$WRAPPER_DIR/build-helpers/dzip.sh" ../mac-langpacks.zip mac-langpacks
diff --git a/gitian/versions b/gitian/versions
index 3df967e..b833342 100755
--- a/gitian/versions
+++ b/gitian/versions
@@ -1,5 +1,9 @@
 TORBROWSER_VERSION_TYPE=release
 BUNDLE_LOCALES="ar de es-ES fa fr it ko nl pl pt-PT ru tr vi zh-CN"
+BUNDLE_LOCALES_LINUX="ja"
+BUNDLE_LOCALES_WIN32="ja"
+BUNDLE_LOCALES_MAC="ja-JP-mac"
+
 BUILD_PT_BUNDLES=1
 
 VERIFY_TAGS=1
diff --git a/gitian/versions.alpha b/gitian/versions.alpha
index 5005445..f37b98a 100755
--- a/gitian/versions.alpha
+++ b/gitian/versions.alpha
@@ -1,5 +1,8 @@
 TORBROWSER_VERSION_TYPE=alpha
 BUNDLE_LOCALES="ar de es-ES fa fr it ko nl pl pt-PT ru tr vi zh-CN"
+BUNDLE_LOCALES_LINUX="ja"
+BUNDLE_LOCALES_WIN32="ja"
+BUNDLE_LOCALES_MAC="ja-JP-mac"
 BUILD_PT_BUNDLES=1
 
 VERIFY_TAGS=1
diff --git a/gitian/versions.beta b/gitian/versions.beta
index 343d4b5..c2143a0 100755
--- a/gitian/versions.beta
+++ b/gitian/versions.beta
@@ -1,5 +1,8 @@
 TORBROWSER_VERSION_TYPE=beta
 BUNDLE_LOCALES="ar de es-ES fa fr it ko nl pl pt-PT ru tr vi zh-CN"
+BUNDLE_LOCALES_LINUX="ja"
+BUNDLE_LOCALES_WIN32="ja"
+BUNDLE_LOCALES_MAC="ja-JP-mac"
 BUILD_PT_BUNDLES=1
 
 VERIFY_TAGS=1
diff --git a/gitian/versions.nightly b/gitian/versions.nightly
index afb82c5..f0551f5 100755
--- 

[tor-commits] [tor-browser-bundle/maint-5.0] Bug 16973: Add the mar-tools dir to LD_LIBRARY_PATH

2015-09-03 Thread gk
commit f3a1676797a35a63ff2e40f89e6aab169b8661b0
Author: Nicolas Vigier 
Date:   Thu Sep 3 12:11:29 2015 +0200

Bug 16973: Add the mar-tools dir to LD_LIBRARY_PATH
---
 tools/update-responses/update_responses |5 +
 1 file changed, 5 insertions(+)

diff --git a/tools/update-responses/update_responses 
b/tools/update-responses/update_responses
index a371403..a875774 100755
--- a/tools/update-responses/update_responses
+++ b/tools/update-responses/update_responses
@@ -329,6 +329,11 @@ sub extract_martools {
 chdir $old_cwd;
 exit_error "Error extracting $marzip" unless $success;
 $ENV{PATH} .= ":$martools_tmpdir/mar-tools";
+if ($ENV{LD_LIBRARY_PATH}) {
+$ENV{LD_LIBRARY_PATH} .= ":$martools_tmpdir/mar-tools";
+} else {
+$ENV{LD_LIBRARY_PATH} = "$martools_tmpdir/mar-tools";
+}
 }
 
 sub log_step {

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/master] Bug 16973: Add the mar-tools dir to LD_LIBRARY_PATH

2015-09-03 Thread gk
commit 7097c9651a556a314a8265226e2e2c111934a7b0
Author: Nicolas Vigier 
Date:   Thu Sep 3 12:11:29 2015 +0200

Bug 16973: Add the mar-tools dir to LD_LIBRARY_PATH
---
 tools/update-responses/update_responses |5 +
 1 file changed, 5 insertions(+)

diff --git a/tools/update-responses/update_responses 
b/tools/update-responses/update_responses
index bb285fd..b1b3331 100755
--- a/tools/update-responses/update_responses
+++ b/tools/update-responses/update_responses
@@ -331,6 +331,11 @@ sub extract_martools {
 chdir $old_cwd;
 exit_error "Error extracting $marzip" unless $success;
 $ENV{PATH} .= ":$martools_tmpdir/mar-tools";
+if ($ENV{LD_LIBRARY_PATH}) {
+$ENV{LD_LIBRARY_PATH} .= ":$martools_tmpdir/mar-tools";
+} else {
+$ENV{LD_LIBRARY_PATH} = "$martools_tmpdir/mar-tools";
+}
 }
 
 sub log_step {

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [tor-browser-bundle/maint-5.0] Bug 16973: fix gpg keyring path

2015-09-03 Thread gk
commit badf55cb0fdda5c3c893f01f996a29a4e105d3d7
Author: Nicolas Vigier 
Date:   Thu Sep 3 11:35:34 2015 +0200

Bug 16973: fix gpg keyring path

The path defined in config.yml is relative to the tools/update-responses
directory, but we usually run the script from the Makefile in the gitian
directory. This patch makes it work from anywhere.
---
 tools/update-responses/update_responses |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/tools/update-responses/update_responses 
b/tools/update-responses/update_responses
index d238d3a..a371403 100755
--- a/tools/update-responses/update_responses
+++ b/tools/update-responses/update_responses
@@ -421,7 +421,7 @@ sub download_version {
 }
 }
 if (system('gpg', '--no-default-keyring', '--keyring',
-$config->{download}{gpg_keyring}, '--verify',
+"$FindBin::Bin/$config->{download}{gpg_keyring}", '--verify',
 "$tmpdir/sha256sums-unsigned-build.txt.asc",
 "$tmpdir/sha256sums-unsigned-build.txt")) {
 exit_error "Error checking gpg signature for version $version";



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits
diff --git a/src/test/test_keygen.sh b/src/test/test_keygen.sh
index 917a804..87012cd 100755
--- a/src/test/test_keygen.sh
+++ b/src/test/test_keygen.sh
@@ -71,6 +71,7 @@ DATA_DIR=`cd "${DATA_DIR}" && pwd`
 touch "${DATA_DIR}/empty_torrc"
 
 QUIETLY="--hush"
+SILENTLY="--quiet"
 TOR="${TOR_BINARY} ${QUIETLY} --DisableNetwork 1 --ShutdownWaitLength 0 
--ORPort 12345 --ExitRelay 0 -f ${DATA_DIR}/empty_torrc"
 
 # SETUP
@@ -80,9 +81,9 @@ TOR="${TOR_BINARY} ${QUIETLY} --DisableNetwork 1 
--ShutdownWaitLength 0 --ORPort
 # copying them into different keys directories in order to simulate
 # different kinds of configuration problems/issues.
 
 # Step 1: Start Tor with --list-fingerprint.  Make sure everything is there.
there.
 mkdir "${DATA_DIR}/orig"
-${TOR} --DataDirectory "${DATA_DIR}/orig" --list-fingerprint > /dev/null
+${TOR} --DataDirectory "${DATA_DIR}/orig" --list-fingerprint ${SILENTLY} > 
/dev/null
 
 check_dir "${DATA_DIR}/orig/keys"
 check_file "${DATA_DIR}/orig/keys/ed25519_master_id_public_key"
@@ -166,7 +167,7 @@ SRC="${DATA_DIR}/orig"
 
 mkdir -p "${ME}/keys"
 cp "${SRC}/keys/ed25519_master_id_"* "${ME}/keys/"
-${TOR} --DataDirectory "${ME}" --list-fingerprint >/dev/null || die "Tor 
failed when starting with only master key"
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} >/dev/null || 
die "Tor failed when starting with only master key"
 check_files_eq "${SRC}/keys/ed25519_master_id_public_key" 
"${ME}/keys/ed25519_master_id_public_key"
 check_files_eq "${SRC}/keys/ed25519_master_id_secret_key" 
"${ME}/keys/ed25519_master_id_secret_key"
 check_file "${ME}/keys/ed25519_signing_cert"
@@ -224,11 +225,11 @@ SRC="${DATA_DIR}/orig"
 
 mkdir -p "${ME}/keys"
 cp "${SRC}/keys/ed25519_master_id_secret_key" "${ME}/keys/"
-${TOR} --DataDirectory "${ME}" --list-fingerprint > "${ME}/fp1" || die "Tor 
wouldn't start with only unencrypted secret key"
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} > "${ME}/fp1" || 
die "Tor wouldn't start with only unencrypted secret key"
 check_file "${ME}/keys/ed25519_master_id_public_key"
 check_file "${ME}/keys/ed25519_signing_cert"
 check_file "${ME}/keys/ed25519_signing_secret_key"
-${TOR} --DataDirectory "${ME}" --list-fingerprint > "${ME}/fp2" || die "Tor 
wouldn't start again after starting once with only unencrypted secret key."
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} > "${ME}/fp2" || 
die "Tor wouldn't start again after starting once with only unencrypted secret 
key."
 
 check_files_eq "${ME}/fp1" "${ME}/fp2"
 
@@ -288,7 +289,7 @@ cp "${SRC}/keys/ed25519_master_id_secret_key" "${ME}/keys/"
 cp "${SRC}/keys/ed25519_signing_cert" "${ME}/keys/"
 cp "${SRC}/keys/ed25519_signing_secret_key" "${ME}/keys/"
 
-${TOR} --DataDirectory "${ME}" --list-fingerprint >/dev/null || die "Failed 
when starting with missing public key"
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} >/dev/null || 
die "Failed when starting with missing public key"
 check_keys_eq ed25519_master_id_secret_key
 check_keys_eq ed25519_master_id_public_key
 check_keys_eq ed25519_signing_secret_key
@@ -310,7 +311,7 @@ cp "${SRC}/keys/ed25519_master_id_public_key" "${ME}/keys/"
 cp "${SRC}/keys/ed25519_signing_cert" "${ME}/keys/"
 cp "${SRC}/keys/ed25519_signing_secret_key" "${ME}/keys/"
 
-${TOR} --DataDirectory "${ME}" --list-fingerprint >/dev/null || die "Failed 
when starting with offline secret key"
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} >/dev/null || 
die "Failed when starting with offline secret key"
 check_no_file "${ME}/keys/ed25519_master_id_secret_key"
 check_keys_eq ed25519_master_id_public_key
 check_keys_eq ed25519_signing_secret_key
@@ -331,7 +332,7 @@ mkdir -p "${ME}/keys"
 cp "${SRC}/keys/ed25519_signing_cert" "${ME}/keys/"
 cp "${SRC}/keys/ed25519_signing_secret_key" "${ME}/keys/"
 
-${TOR} --DataDirectory "${ME}" --list-fingerprint >/dev/null || die "Failed 
when starting with only signing material"
+${TOR} --DataDirectory "${ME}" --list-fingerprint ${SILENTLY} >/dev/null || 
die "Failed when starting with only signing material"
 check_no_file "${ME}/keys/ed25519_master_id_secret_key"
 check_file "${ME}/keys/ed25519_master_id_public_key"
 check_keys_eq ed25519_signing_secret_key

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [webwml/master] Fix date format on press page

2015-09-03 Thread sebastian
commit 31164fb66957d925709bcc91fd9d1ff8bd5dbe30
Author: Sebastian Hahn 
Date:   Thu Sep 3 21:11:33 2015 +0200

Fix date format on press page
---
 press/en/press.wml |   32 
 1 file changed, 16 insertions(+), 16 deletions(-)
@@ -80,9 +81,9 @@ TOR="${TOR_BINARY} ${QUIETLY} --DisableNetwork 1 
 # different kinds of configuration problems/issues.
 
-# Step 1: Start Tor with --list-fingerprint.  Make sure everything is there.
+# Step 1: Start Tor with --list-fingerprint --quiet.  Make sure everything is 
there.
 mkdir "${DATA_DIR}/orig"
